@@ -93,6 +93,7 @@
 #include "dsda/data_organizer.h"
 #include "dsda/map_format.h"
 #include "dsda/mapinfo.h"
+#include "dsda/gameinfo.h"
 #include "dsda/mobjinfo.h"
 #include "dsda/options.h"
 #include "dsda/pause.h"
@@ -122,6 +123,10 @@
 
 static void D_PageDrawer(void);
 
+char* iwadlump;
+char* iwadver;
+int EpisodeStructure = false;
+
 // jff 1/24/98 add new versions of these variables to remember command line
 dboolean clnomonsters;   // checkparm of -nomonsters
 dboolean clrespawnparm;  // checkparm of -respawn
@@ -168,8 +173,11 @@ const char *const standard_iwads[]=
   "freedoom1.wad",
   "freedm.wad",
 
-  "hacx.wad",
   "chex.wad",
+  "chex3v.wad",
+  "chex3d2.wad",
+
+  "hacx.wad",
   "rekkrsa.wad",
 
   "bfgdoom2.wad",
@@ -180,8 +188,27 @@ const char *const standard_iwads[]=
 
   "heretic1.wad"
 };
+
+// list of episode-formatted IWAD names
+const char *const episode_iwads[]=
+{
+  "doom.wad",
+  "doom1.wad",
+  "doomu.wad", /* CPhipps - alow doomu.wad */
+
+  "freedoom1.wad",
+
+  "chex.wad",
+  "rekkrsa.wad",
+
+  "heretic.wad",
+
+  "heretic1.wad"
+};
+
 //e6y static
 const int nstandard_iwads = sizeof standard_iwads/sizeof*standard_iwads;
+const int nepisode_iwads = sizeof episode_iwads/sizeof*episode_iwads;
 
 /*
  * D_PostEvent - Event handling
@@ -499,6 +526,11 @@ void D_Display (fixed_t frac)
     D_DrawPause();
   }
 
+  V_BeginUIDraw();
+  if (M_MenuIsShaded())
+    M_ShadedScreen(0);
+  V_EndUIDraw();
+
   // menus go directly to the screen
   M_Drawer();          // menu is drawn even on top of everything
 
@@ -612,6 +644,7 @@ static int  demosequence;         // killough 5/2/98: made static
 static int  pagetic;
 static const char *pagename; // CPhipps - const
 dboolean bfgedition = 0;
+dboolean freedm = 0;
 
 //
 // D_PageTicker
@@ -879,6 +912,7 @@ void CheckIWAD(const char *iwadname,GameMode_t *gmode,dboolean *hassec)
     int ud=0,rg=0,sw=0,cm=0,sc=0,hx=0;
     dboolean dmenupic = false;
     dboolean large_titlepic = false;
+    dboolean freedm_lmp = false;
     FILE* fp;
 
     // Identify IWAD correctly
@@ -943,6 +977,8 @@ void CheckIWAD(const char *iwadname,GameMode_t *gmode,dboolean *hassec)
             large_titlepic = true;
           if (!strncmp(fileinfo[length].name,"HACX",4))
             hx++;
+          if (!strncmp(fileinfo[length].name,"FREEDM",6))
+            freedm_lmp = true;
         }
         Z_Free(fileinfo);
 
@@ -956,6 +992,8 @@ void CheckIWAD(const char *iwadname,GameMode_t *gmode,dboolean *hassec)
     // unity iwad has dmenupic and a large titlepic
     if (dmenupic && !large_titlepic)
       bfgedition++;
+    if (freedm_lmp)
+      freedm++;
 
     // Determine game mode from levels present
     // Must be a full set for whichever mode is present
@@ -1028,7 +1066,13 @@ void AddIWAD(const char *iwad)
     case shareware:
       gamemission = doom;
       if (i>=8 && !strnicmp(iwad+i-8,"chex.wad",8))
-        gamemission = chex;
+        gamemission = tc_chex;
+      else if (i>=10 && !strnicmp(iwad+i-10,"chex3v.wad",10))
+        gamemission = tc_chex3v;
+      else if (i>=11 && !strnicmp(iwad+i-11,"rekkrsa.wad",11))
+        gamemission = tc_rekkr;
+      else if (i>=13 && !strnicmp(iwad+i-13,"freedoom1.wad",13))
+        gamemission = tc_freedoom;
       break;
     case commercial:
       gamemission = doom2;
@@ -1038,8 +1082,13 @@ void AddIWAD(const char *iwad)
         gamemission = pack_tnt;
       else if (i>=12 && !strnicmp(iwad+i-12,"plutonia.wad",12))
         gamemission = pack_plut;
+      else if (i>=11 && !strnicmp(iwad+i-11,"chex3d2.wad",11))
+        gamemission = tc_chex3v;
       else if (i>=8 && !strnicmp(iwad+i-8,"hacx.wad",8))
-        gamemission = hacx;
+        gamemission = tc_hacx;
+      else if ((i>=13 && !strnicmp(iwad+i-13,"freedoom2.wad",13))
+            || (i>=10 && !strnicmp(iwad+i-10,"freedm.wad",10)))
+        gamemission = tc_freedoom;
       break;
     default:
       gamemission = none;
@@ -1048,6 +1097,10 @@ void AddIWAD(const char *iwad)
   if (gamemode == indetermined)
     //jff 9/3/98 use logical output routine
     lprintf(LO_WARN,"Unknown Game Version, may not work\n");
+
+  // Set up TC game logic
+  tc_game = (gamemission > pack_nerve);
+
   D_AddFile(iwad,source_iwad);
 }
 
@@ -1076,6 +1129,7 @@ static char *FindIWADFile(void)
   int   i;
   dsda_arg_t* arg;
   char  * iwad  = NULL;
+  int iwadnum = EpisodeStructure ? nepisode_iwads : nstandard_iwads;
 
   if (CheckExeSuffix("-heretic"))
   {
@@ -1100,8 +1154,11 @@ static char *FindIWADFile(void)
     else if (dsda_Flag(dsda_arg_hexen))
       return I_FindWad("hexen.wad");
 
-    for (i=0; !iwad && i<nstandard_iwads; i++)
-      iwad = I_FindWad(standard_iwads[i]);
+    if (iwadlump != NULL)
+      return I_FindWad(iwadlump);
+
+    for (i=0; !iwad && i<iwadnum; i++)
+      iwad = EpisodeStructure ? I_FindWad(episode_iwads[i]) : I_FindWad(standard_iwads[i]);
   }
   return iwad;
 }
@@ -1127,52 +1184,6 @@ static dboolean FileMatchesIWAD(const char *name)
   return false;
 }
 
-//
-// IdentifyVersion
-//
-// Set the location of the defaults file and the savegame root
-// Locate and validate an IWAD file
-// Determine gamemode from the IWAD
-//
-// supports IWADs with custom names. Also allows the -iwad parameter to
-// specify which iwad is being searched for if several exist in one dir.
-// The -iwad parm may specify:
-//
-// 1) a specific pathname, which must exist (.wad optional)
-// 2) or a directory, which must contain a standard IWAD,
-// 3) or a filename, which must be found in one of the standard places:
-//   a) current dir,
-//   b) exe dir
-//   c) $DOOMWADDIR
-//   d) or $HOME
-//
-// jff 4/19/98 rewritten to use a more advanced search algorithm
-
-static void IdentifyVersion (void)
-{
-  char *iwad;
-
-  // why is this here?
-  dsda_InitDataDir();
-  dsda_InitSaveDir();
-
-  // locate the IWAD and determine game mode from it
-
-  iwad = FindIWADFile();
-
-  if (iwad && *iwad)
-  {
-    AddIWAD(iwad);
-    Z_Free(iwad);
-  }
-  else
-  {
-    I_Error("IdentifyVersion: IWAD not found\n\n"
-            "Make sure your IWADs are in a folder that dsda-doom searches on\n"
-            "For example: %s", I_ConfigDir());
-  }
-}
-
 //
 // DoLooseFiles
 //
@@ -1400,6 +1411,21 @@ static void D_AddZip(const char* zipped_file_name, wad_source_t source, deh_queu
   full_zip_path = I_RequireZip(zipped_file_name);
   temporary_directory = dsda_UnzipFile(full_zip_path);
 
+  LoadWADsAtPath(temporary_directory, source);
+  if (MainLumpCache)
+     LoadDehackedFilesAtPath(temporary_directory, true, deh_queue);
+
+  Z_Free(full_zip_path);
+}
+
+static void D_AddUnzippedFile(const char* zipped_file_name, wad_source_t source, deh_queue_t *deh_queue)
+{
+  char* full_zip_path;
+  const char* temporary_directory;
+
+  full_zip_path = I_RequireZip(zipped_file_name);
+  temporary_directory = dsda_ReadUnzippedFile(full_zip_path);
+
   LoadWADsAtPath(temporary_directory, source);
   LoadDehackedFilesAtPath(temporary_directory, true, deh_queue);
 
@@ -1430,7 +1456,11 @@ static const char *D_AutoLoadGameBase()
 {
   return hexen ? "hexen-all" :
          heretic ? "heretic-all" :
-         "doom-all";
+         (gamemission == tc_chex ||
+         gamemission == tc_chex3v) ? "chex-all" :
+         (gamemission == tc_freedoom) ? "freedoom-all" :
+         !tc_game ? "doom-all":
+         NULL;
 }
 
 #define ALL_AUTOLOAD "all-all"
@@ -1447,11 +1477,14 @@ void D_AutoloadIWadDir()
   LoadZIPsAtPath(autoload_dir, source_auto_load, &autoload_deh_all_queue);
   Z_Free(autoload_dir);
 
-  // common auto-loaded files for the game
-  autoload_dir = GetAutoloadDir(D_AutoLoadGameBase(), true);
-  LoadWADsAtPath(autoload_dir, source_auto_load);
-  LoadZIPsAtPath(autoload_dir, source_auto_load, &autoload_deh_game_queue);
-  Z_Free(autoload_dir);
+  if (D_AutoLoadGameBase())
+  {
+    // common auto-loaded files for the game
+    autoload_dir = GetAutoloadDir(D_AutoLoadGameBase(), true);
+    LoadWADsAtPath(autoload_dir, source_auto_load);
+    LoadZIPsAtPath(autoload_dir, source_auto_load, &autoload_deh_game_queue);
+    Z_Free(autoload_dir);
+  }
 
   // auto-loaded files per IWAD
   autoload_dir = GetAutoloadDir(IWADBaseName(), true);
@@ -1490,11 +1523,14 @@ static void D_AutoloadDehIWadDir()
   D_ProcessDehAutoloadQueue(&autoload_deh_all_queue);
   Z_Free(autoload_dir);
 
-  // common auto-loaded files for the game
-  autoload_dir = GetAutoloadDir(D_AutoLoadGameBase(), true);
-  LoadDehackedFilesAtPath(autoload_dir, false, NULL);
-  D_ProcessDehAutoloadQueue(&autoload_deh_game_queue);
-  Z_Free(autoload_dir);
+  if (D_AutoLoadGameBase())
+  {
+    // common auto-loaded files for the game
+    autoload_dir = GetAutoloadDir(D_AutoLoadGameBase(), true);
+    LoadDehackedFilesAtPath(autoload_dir, false, NULL);
+    D_ProcessDehAutoloadQueue(&autoload_deh_game_queue);
+    Z_Free(autoload_dir);
+  }
 
   // auto-loaded files per IWAD
   autoload_dir = GetAutoloadDir(IWADBaseName(), true);
@@ -1605,9 +1641,18 @@ static void EvaluateDoomVerStr(void)
       case retail:
         switch (gamemission)
         {
-          case chex:
+          case tc_chex:
             doomverstr = "Chex(R) Quest";
             break;
+          case tc_chex3v:
+            doomverstr = "Chex(R) Quest 3: Vanilla Edition";
+            break;
+          case tc_rekkr:
+            doomverstr = "REKKR";
+            break;
+          case tc_freedoom:
+            doomverstr = "Freedoom Phase 1";
+            break;
           default:
             doomverstr = "The Ultimate DOOM";
             break;
@@ -1628,9 +1673,15 @@ static void EvaluateDoomVerStr(void)
           case pack_tnt:
             doomverstr = "Final DOOM - TNT: Evilution";
             break;
-          case hacx:
+          case tc_chex3v:
+            doomverstr = "Chex(R) Quest 3: Modding Edition";
+            break;
+          case tc_hacx:
             doomverstr = "HACX - Twitch 'n Kill";
             break;
+          case tc_freedoom:
+            doomverstr = freedm ? "FreeDM" : "Freedoom Phase 2";
+            break;
           default:
             doomverstr = "DOOM 2: Hell on Earth";
             break;
@@ -1658,11 +1709,183 @@ static void EvaluateDoomVerStr(void)
           "%s is released under the GNU General Public license v2.0.\n"
           "You are welcome to redistribute it under certain conditions.\n"
           "It comes with ABSOLUTELY NO WARRANTY. See the file COPYING for details.\n\n",
-          PACKAGE_NAME);
+          PROJECT_NAME);
 
   lprintf(LO_INFO, "Playing: %s\n", doomverstr);
 }
 
+static void dsda_Loadfiles(void)
+{
+  dsda_arg_t *arg;
+
+  if ((arg = dsda_Arg(dsda_arg_file))->found)
+  {
+    int file_i;
+    // the parms after p are wadfile/lump names,
+    // until end of parms or another - preceded parm
+    modifiedgame = true;            // homebrew levels
+
+    for (file_i = 0; file_i < arg->count; ++file_i)
+    {
+      const char* file_name;
+      char *file = NULL;
+
+      file_name = arg->value.v_string_array[file_i];
+
+      if (!dsda_FileExtension(file_name))
+      {
+        const char *extensions[] = { ".wad", ".lmp", ".zip", ".deh", ".bex", NULL };
+
+        file = I_RequireAnyFile(file_name, extensions);
+        file_name = file;
+      }
+
+      if (dsda_HasFileExt(file_name, ".deh") || dsda_HasFileExt(file_name, ".bex"))
+      {
+        if (MainLumpCache)
+          dsda_AppendStringArg(dsda_arg_deh, file_name);
+      }
+      else if (dsda_HasFileExt(file_name, ".zip"))
+      {
+        if (dsda_Arg(dsda_arg_iwad)->found)
+           D_AddZip(file_name, source_pwad, NULL);
+         else
+           MainLumpCache ? D_AddUnzippedFile(file_name, source_pwad, NULL) : D_AddZip(file_name, source_pwad, NULL);
+      }
+      else if (dsda_HasFileExt(file_name, ".wad") || dsda_HasFileExt(file_name, ".lmp"))
+      {
+        if (!file)
+          file = I_RequireWad(file_name);
+
+        D_AddFile(file, source_pwad);
+      }
+      else
+      {
+        I_Error("File type \"%s\" is not supported", dsda_FileExtension(file_name));
+      }
+
+      Z_Free(file);
+    }
+  }
+}
+
+//
+// DetectEpisodeStructure
+//
+// If GAMEINFO is not present but Doom 1 maps are found, autoload episode IWAD.
+//
+
+static void dsda_DetectEpisodeStructure(void)
+{
+  int i, ii;
+  char lump[5];
+  char *iwad;
+
+  for (i=0;i<10;i++)
+  {
+    for (ii=0;ii<10;ii++)
+    {
+      sprintf(lump, "E%dM%d", i, ii);
+      if (W_LumpNameExists(lump))
+      {
+        EpisodeStructure = true;
+        iwadver = Z_Strdup(lump);
+        iwad = FindIWADFile();
+
+        if (iwad)
+          iwadlump = Z_Strdup(iwad);
+
+        return;
+      }
+    }
+  }
+}
+
+//
+// IdentifyVersion
+//
+// Set the location of the defaults file and the savegame root
+// Locate and validate an IWAD file
+// Determine gamemode from the IWAD
+//
+// supports IWADs with custom names. Also allows the -iwad parameter to
+// specify which iwad is being searched for if several exist in one dir.
+// The -iwad parm may specify:
+//
+// 1) a specific pathname, which must exist (.wad optional)
+// 2) or a directory, which must contain a standard IWAD,
+// 3) or a filename, which must be found in one of the standard places:
+//   a) current dir,
+//   b) exe dir
+//   c) $DOOMWADDIR
+//   d) or $HOME
+//
+// jff 4/19/98 rewritten to use a more advanced search algorithm
+
+static void IdentifyVersion (void)
+{
+  char *iwad = NULL;
+
+  // why is this here?
+  dsda_InitDataDir();
+  dsda_InitSaveDir();
+
+  if (!dsda_Arg(dsda_arg_iwad)->found)
+  {
+    dsda_Loadfiles();  // Load files for GAMEINFO lump
+    if (!dsda_Flag(dsda_arg_noautoload)) D_AutoloadPWadDir(); // Load autoload PWAD files for GAMEINFO lump
+    W_Init(); // Quick cache to search for GAMEINFO lump
+
+    // Parse GAMEINFO lump
+    dsda_LoadGameInfo();
+
+    // Autodetect Doom 1 maps
+    if (iwadlump == NULL)
+      dsda_DetectEpisodeStructure();
+
+    // Reset lump cache
+    dsda_ResetInitLumpCache();
+
+    // If IWAD found, check if it exists
+    if (iwadlump != NULL)
+    {
+      iwad = FindIWADFile();
+
+      // Clear data if IWAD not found
+      if (!(iwad && *iwad))
+      {
+        Z_Free(iwadlump);
+        Z_Free(iwadver);
+        iwadlump = NULL;
+        iwadver = NULL;
+      }
+    }
+  }
+
+  // If GAMEINFO / Episode IWAD not found,
+  // locate IWAD the traditional way
+  if (iwadlump == NULL)
+  {
+    EpisodeStructure = false;
+    iwad = FindIWADFile();
+  }
+
+  // It is now ok to load dehacked / unzip files
+  MainLumpCache = true;
+
+  if (iwad && *iwad)
+  {
+    AddIWAD(iwad);
+    Z_Free(iwad);
+  }
+  else
+  {
+    I_Error("IdentifyVersion: IWAD not found\n\n"
+            "Make sure your IWADs are in a folder that dsda-doom searches on\n"
+            "For example: %s", I_ConfigDir());
+  }
+}
+
 //
 // D_DoomMainSetup
 //
@@ -1683,9 +1906,12 @@ static void D_DoomMainSetup(void)
     I_SafeExit(0);
   }
 
+  // CPhipps - autoloading of wads
+  autoload = !dsda_Flag(dsda_arg_noautoload);
+
   DoLooseFiles();  // Ty 08/29/98 - handle "loose" files on command line
 
-  IdentifyVersion();
+  IdentifyVersion(); // Get IWAD
 
   dsda_InitGlobal();
 
@@ -1767,9 +1993,6 @@ static void D_DoomMainSetup(void)
   //e6y: some stuff from command-line should be initialised before ProcessDehFile()
   e6y_InitCommandLine();
 
-  // CPhipps - autoloading of wads
-  autoload = !dsda_Flag(dsda_arg_noautoload);
-
   D_AddFile(port_wad_file, source_auto_load);
 
   HandlePlayback(); // must come before autoload: may detect iwad in footer
@@ -1783,51 +2006,7 @@ static void D_DoomMainSetup(void)
   // add any files specified on the command line with -file wadfile
   // to the wad list
 
-  if ((arg = dsda_Arg(dsda_arg_file))->found)
-  {
-    int file_i;
-    // the parms after p are wadfile/lump names,
-    // until end of parms or another - preceded parm
-    modifiedgame = true;            // homebrew levels
-
-    for (file_i = 0; file_i < arg->count; ++file_i)
-    {
-      const char* file_name;
-      char *file = NULL;
-
-      file_name = arg->value.v_string_array[file_i];
-
-      if (!dsda_FileExtension(file_name))
-      {
-        const char *extensions[] = { ".wad", ".lmp", ".zip", ".deh", ".bex", NULL };
-
-        file = I_RequireAnyFile(file_name, extensions);
-        file_name = file;
-      }
-
-      if (dsda_HasFileExt(file_name, ".deh") || dsda_HasFileExt(file_name, ".bex"))
-      {
-        dsda_AppendStringArg(dsda_arg_deh, file_name);
-      }
-      else if (dsda_HasFileExt(file_name, ".zip"))
-      {
-        D_AddZip(file_name, source_pwad, NULL);
-      }
-      else if (dsda_HasFileExt(file_name, ".wad") || dsda_HasFileExt(file_name, ".lmp"))
-      {
-        if (!file)
-          file = I_RequireWad(file_name);
-
-        D_AddFile(file, source_pwad);
-      }
-      else
-      {
-        I_Error("File type \"%s\" is not supported", dsda_FileExtension(file_name));
-      }
-
-      Z_Free(file);
-    }
-  }
+  dsda_Loadfiles();
 
   // add wad files from autoload PWAD directories
   if (autoload)
@@ -1855,6 +2034,16 @@ static void D_DoomMainSetup(void)
 
   lprintf(LO_DEBUG, "G_ReloadDefaults: Checking OPTIONS.\n");
   dsda_ParseOptionsLump();
+
+  if (iwadlump != NULL)
+  {
+    lprintf(LO_INFO, "Detected %s lump: %s\n", iwadver ? iwadver : "GAMEINFO", iwadlump);
+    Z_Free(iwadlump);
+
+    if (iwadver)
+      Z_Free(iwadver);
+  }
+
   G_ReloadDefaults();
 
   // e6y
@@ -1885,7 +2074,7 @@ static void D_DoomMainSetup(void)
         ProcessDehFile(NULL, D_dehout(), lump);
       }
     }
-    if (gamemission == chex)
+    if (gamemission == tc_chex)
     {
       int lump = W_CheckNumForName2("CHEXDEH", ns_prboom);
       if (lump != LUMP_NOT_FOUND)
