@@ -268,6 +268,11 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "tracks when 100% kills is reached",
     arg_null,
   },
+  [dsda_arg_track_reality] = {
+    "-track_reality", NULL, NULL,
+    "tracks reality and almost reality categories restrictions",
+    arg_null,
+  },
   [dsda_arg_time_keys] = {
     "-time_keys", NULL, "105",
     "announces the time when keys are picked up",
