@@ -83,7 +83,7 @@ extern int dsda_input_profile;
 extern int weapon_preferences[2][NUMWEAPONS + 1];
 extern int demo_smoothturns;
 extern int demo_smoothturnsfactor;
-extern int sts_always_red;
+extern int sts_colored_numbers;
 extern int sts_pct_always_gray;
 extern int sts_traditional_keys;
 extern int full_sounds;
@@ -126,6 +126,7 @@ void R_SetViewSize(void);
 void M_ChangeApplyPalette(void);
 void M_ChangeStretch(void);
 void M_ChangeAspectRatio(void);
+void dsda_RefreshLinearSky(void);
 void deh_changeCompTranslucency(void);
 void dsda_InitGameControllerParameters(void);
 void dsda_InitExHud(void);
@@ -299,9 +300,9 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "weapon_attack_alignment", dsda_config_weapon_attack_alignment,
     dsda_config_int, 0, 3, { 0 }, NULL, STRICT_INT(0)
   },
-  [dsda_config_sts_always_red] = {
-    "sts_always_red", dsda_config_sts_always_red,
-    CONF_BOOL(1), &sts_always_red
+  [dsda_config_sts_colored_numbers] = {
+    "sts_colored_numbers", dsda_config_sts_colored_numbers,
+    CONF_BOOL(0), &sts_colored_numbers
   },
   [dsda_config_sts_pct_always_gray] = {
     "sts_pct_always_gray", dsda_config_sts_pct_always_gray,
@@ -373,7 +374,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_cheat_codes] = {
     "dsda_cheat_codes", dsda_config_cheat_codes,
-    CONF_BOOL(1)
+    CONF_BOOL(1), NULL, STRICT_INT(0)
   },
   [dsda_config_organize_failed_demos] = {
     "dsda_organize_failed_demos", dsda_config_organize_failed_demos,
@@ -539,10 +540,18 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "mapcolor_revsecr", dsda_config_mapcolor_revsecr,
     CONF_COLOR(112), &mapcolor.revsecr
   },
+  [dsda_config_mapcolor_tagfinder] = {
+    "mapcolor_tagfinder", dsda_config_mapcolor_tagfinder,
+    CONF_COLOR(252), &mapcolor.tagfinder
+  },
   [dsda_config_mapcolor_exit] = {
     "mapcolor_exit", dsda_config_mapcolor_exit,
     CONF_COLOR(0), &mapcolor.exit
   },
+  [dsda_config_mapcolor_exitsecr] = {
+    "mapcolor_exitsecr", dsda_config_mapcolor_exitsecr,
+    CONF_COLOR(0), &mapcolor.exitsecr
+  },
   [dsda_config_mapcolor_unsn] = {
     "mapcolor_unsn", dsda_config_mapcolor_unsn,
     CONF_COLOR(104), &mapcolor.unsn
@@ -666,7 +675,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_movement_strafe50onturns] = {
     "movement_strafe50onturns", dsda_config_movement_strafe50onturns,
-    CONF_BOOL(0), NULL, NOT_STRICT, M_ChangeSpeed
+    CONF_BOOL(0), NULL, STRICT_INT(0), M_ChangeSpeed
   },
   [dsda_config_movement_shorttics] = {
     "movement_shorttics", dsda_config_movement_shorttics,
@@ -826,7 +835,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_hudadd_crosshair_target_color] = {
     "hudadd_crosshair_target_color", dsda_config_hudadd_crosshair_target_color,
-    CONF_CR(9)
+    CONF_CR(9), NULL, STRICT_INT(9)
   },
   [dsda_config_hud_displayed] = {
     "hud_displayed", dsda_config_hud_displayed,
@@ -886,7 +895,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_auto_key_frame_interval] = {
     "dsda_auto_key_frame_interval", dsda_config_auto_key_frame_interval,
-    dsda_config_int, 1, 600, { 1 }, NULL, NOT_STRICT, dsda_InitKeyFrame
+    dsda_config_int, 1, 600, { 1 }, NULL, STRICT_INT(1), dsda_InitKeyFrame
   },
   [dsda_config_auto_key_frame_depth] = {
     "dsda_auto_key_frame_depth", dsda_config_auto_key_frame_depth,
@@ -894,11 +903,11 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_auto_key_frame_timeout] = {
     "dsda_auto_key_frame_timeout", dsda_config_auto_key_frame_timeout,
-    dsda_config_int, 0, 25, { 10 }, NULL, NOT_STRICT, dsda_InitKeyFrame
+    dsda_config_int, 0, 25, { 10 }, NULL, STRICT_INT(0), dsda_InitKeyFrame
   },
   [dsda_config_auto_save] = {
     "dsda_config_auto_save", dsda_config_auto_save,
-    CONF_BOOL(0)
+    CONF_BOOL(0), NULL, STRICT_INT(0)
   },
   [dsda_config_ex_text_scale_x] = {
     "ex_text_scale_x", dsda_config_ex_text_scale_x,
@@ -910,7 +919,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_wipe_at_full_speed] = {
     "dsda_wipe_at_full_speed", dsda_config_wipe_at_full_speed,
-    CONF_BOOL(1)
+    CONF_BOOL(1), NULL, STRICT_INT(0)
   },
   [dsda_config_show_demo_attempts] = {
     "dsda_show_demo_attempts", dsda_config_show_demo_attempts,
@@ -930,11 +939,11 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_command_history_size] = {
     "dsda_command_history_size", dsda_config_command_history_size,
-    dsda_config_int, 1, 20, { 10 }, NULL, NOT_STRICT, dsda_InitCommandHistory
+    dsda_config_int, 1, 20, { 10 }, NULL, STRICT_INT(0), dsda_InitCommandHistory
   },
   [dsda_config_hide_empty_commands] = {
     "dsda_hide_empty_commands", dsda_config_hide_empty_commands,
-    CONF_BOOL(1), NULL, NOT_STRICT, dsda_InitCommandHistory
+    CONF_BOOL(1), NULL, STRICT_INT(0), dsda_InitCommandHistory
   },
   [dsda_config_skip_quit_prompt] = {
     "dsda_skip_quit_prompt", dsda_config_skip_quit_prompt,
@@ -962,7 +971,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_pistol_start] = {
     "dsda_pistol_start", dsda_config_pistol_start,
-    CONF_BOOL(0)
+    CONF_BOOL(0), NULL, NOT_STRICT
   },
   [dsda_config_respawn_monsters] = {
     "dsda_respawn_monsters", dsda_config_respawn_monsters,
@@ -1036,13 +1045,17 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "map_title", dsda_config_map_title,
     CONF_BOOL(1), NULL, NOT_STRICT, dsda_RefreshMapTitle
   },
-  [dsda_config_map_trail_mode] = {
-    "map_trail_mode", dsda_config_map_trail_mode,
-    dsda_config_int, 0, map_trail_mode_max - 1, { 0 }, NULL, NOT_STRICT, AM_initPlayerTrail
+  [dsda_config_map_trail] = {
+    "map_trail", dsda_config_map_trail,
+    CONF_BOOL(0), NULL, STRICT_INT(0), AM_initPlayerTrail
+  },
+  [dsda_config_map_trail_collisions] = {
+    "map_trail_collisions", dsda_config_map_trail_collisions,
+    CONF_BOOL(0), NULL, STRICT_INT(0), AM_initPlayerTrail
   },
   [dsda_config_map_trail_size] = {
     "map_trail_size", dsda_config_map_trail_size,
-    dsda_config_int, 0, 350, { 105 }, NULL, NOT_STRICT, AM_initPlayerTrail
+    dsda_config_int, 0, 350, { 105 }, NULL, STRICT_INT(0), AM_initPlayerTrail
   },
   [dsda_config_automap_overlay] = {
     "automap_overlay", dsda_config_automap_overlay,
@@ -1086,11 +1099,11 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_map_textured_trans] = {
     "map_textured_trans", dsda_config_map_textured_trans,
-    dsda_config_int, 0, 100, { 100 }, NULL, NOT_STRICT, gld_ResetAutomapTransparency
+    dsda_config_int, 0, 100, { 100 }, NULL, STRICT_INT(0), gld_ResetAutomapTransparency
   },
   [dsda_config_map_textured_overlay_trans] = {
     "map_textured_overlay_trans", dsda_config_map_textured_overlay_trans,
-    dsda_config_int, 0, 100, { 66 }, NULL, NOT_STRICT, gld_ResetAutomapTransparency
+    dsda_config_int, 0, 100, { 66 }, NULL, STRICT_INT(0), gld_ResetAutomapTransparency
   },
   [dsda_config_map_lines_overlay_trans] = {
     "map_lines_overlay_trans", dsda_config_map_lines_overlay_trans,
@@ -1147,7 +1160,11 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_sdl_video_window_pos] = {
     "sdl_video_window_pos", dsda_config_sdl_video_window_pos,
-    CONF_STRING("center")
+    CONF_STRING("")
+  },
+  [dsda_config_sdl_video_display_index] = {
+    "sdl_video_display_index", dsda_config_sdl_video_display_index,
+    dsda_config_int, 0, 10, { 0 }, NULL, NOT_STRICT
   },
   [dsda_config_palette_ondamage] = {
     "palette_ondamage", dsda_config_palette_ondamage,
@@ -1203,6 +1220,14 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "render_stretchsky", dsda_config_render_stretchsky,
     CONF_BOOL(1)
   },
+  [dsda_config_render_linearsky] = {
+    "render_linearsky", dsda_config_render_linearsky,
+    CONF_BOOL(0), NULL, NOT_STRICT, dsda_RefreshLinearSky
+  },
+  [dsda_config_aspect_ratio_correction] = {
+    "aspect_ratio_correction", dsda_config_aspect_ratio_correction,
+    CONF_BOOL(1), NULL, NOT_STRICT
+  },
   [dsda_config_gl_fade_mode] = {
     "gl_fade_mode", dsda_config_gl_fade_mode,
     dsda_config_int, 0, 1, { 0 }
@@ -1523,8 +1548,8 @@ int dsda_IntConfig(dsda_config_identifier_t id) {
   return dsda_config[id].transient_value.v_int;
 }
 
-int dsda_PersistentIntConfig(dsda_config_identifier_t id) {
-  return dsda_config[id].persistent_value.v_int;
+dboolean dsda_IsStrictConfig(dsda_config_identifier_t id) {
+  return dsda_config[id].flags & CONF_STRICT;
 }
 
 int dsda_TransientIntConfig(dsda_config_identifier_t id) {
@@ -1535,10 +1560,6 @@ const char* dsda_StringConfig(dsda_config_identifier_t id) {
   return dsda_config[id].transient_value.v_string;
 }
 
-const char* dsda_PersistentStringConfig(dsda_config_identifier_t id) {
-  return dsda_config[id].persistent_value.v_string;
-}
-
 char* dsda_ConfigSummary(const char* name) {
   int id;
   char* summary = NULL;
