@@ -178,7 +178,7 @@ static void dsda_LoadCRLumps(byte* buffer) {
   int i;
   byte* blood_buffer;
 
-  blood_buffer = buffer + CR_HUD_LIMIT * 256;
+  blood_buffer = buffer + CR_BLOOD * 256;
 
   for (i = 0; i < CR_LIMIT - CR_BLOOD; ++i) {
     int lump;
@@ -197,6 +197,7 @@ byte* dsda_GenerateCRTable(void) {
   int check_i;
   byte* buffer;
   const byte* playpal;
+  int dark_i;
 
   dsda_LoadCRLump();
 
@@ -221,49 +222,57 @@ byte* dsda_GenerateCRTable(void) {
     if (orig_i == 176)
       length = 1;
 
-    for (cr_i = 0; cr_i < CR_HUD_LIMIT; ++cr_i) {
-      int target_r, target_g, target_b;
-      int best_i = 0;
-      int best_dist = INT_MAX;
+    for (dark_i = 0; dark_i < 2; ++dark_i) {
+      for (cr_i = 0; cr_i < CR_DARKEN; ++cr_i) {
+        int target_r, target_g, target_b;
+        int best_i = 0;
+        int best_dist = INT_MAX;
 
-      target_r = cr_range[cr_i].r1 +
-                 (int) (length * (cr_range[cr_i].r2 - cr_range[cr_i].r1));
-      target_g = cr_range[cr_i].g1 +
-                 (int) (length * (cr_range[cr_i].g2 - cr_range[cr_i].g1));
-      target_b = cr_range[cr_i].b1 +
-                 (int) (length * (cr_range[cr_i].b2 - cr_range[cr_i].b1));
+        target_r = cr_range[cr_i].r1 +
+                  (int) (length * (cr_range[cr_i].r2 - cr_range[cr_i].r1));
+        target_g = cr_range[cr_i].g1 +
+                  (int) (length * (cr_range[cr_i].g2 - cr_range[cr_i].g1));
+        target_b = cr_range[cr_i].b1 +
+                  (int) (length * (cr_range[cr_i].b2 - cr_range[cr_i].b1));
 
-      for (check_i = 0; check_i < 768; check_i += 3) {
-        int dist;
-        int dist_r, dist_g, dist_b;
-        int avg_r;
-
-        avg_r = (target_r + playpal[check_i + 0]) / 2;
-        dist_r = target_r - playpal[check_i + 0];
-        dist_g = target_g - playpal[check_i + 1];
-        dist_b = target_b - playpal[check_i + 2];
-
-        // This equation seems to fix issues with red-dominant translation,
-        // e.g., aaliens CR_BRICK, which has artifacts in the second equation.
-        //
-        // I experimented with more "sophisticated" approaches,
-        // but they don't seem to do well with common palettes.
-        if (target_r > target_g && target_r > target_b)
-          dist = (((512 + avg_r) * dist_r * dist_r) >> 8) +
-                 4 * dist_g * dist_g +
-                 (((767 - avg_r) * dist_b * dist_b) >> 8);
-        else
-          dist = dist_r * dist_r +
-                 dist_g * dist_g +
-                 dist_b * dist_b;
-
-        if (dist < best_dist) {
-          best_dist = dist;
-          best_i = check_i / 3;
+        if (dark_i) {
+          target_r /= 2;
+          target_g /= 2;
+          target_b /= 2;
         }
-      }
 
-      buffer[cr_i * 256 + orig_i] = best_i;
+        for (check_i = 0; check_i < 768; check_i += 3) {
+          int dist;
+          int dist_r, dist_g, dist_b;
+          int avg_r;
+
+          avg_r = (target_r + playpal[check_i + 0]) / 2;
+          dist_r = target_r - playpal[check_i + 0];
+          dist_g = target_g - playpal[check_i + 1];
+          dist_b = target_b - playpal[check_i + 2];
+
+          // This equation seems to fix issues with red-dominant translation,
+          // e.g., aaliens CR_BRICK, which has artifacts in the second equation.
+          //
+          // I experimented with more "sophisticated" approaches,
+          // but they don't seem to do well with common palettes.
+          if (target_r > target_g && target_r > target_b)
+            dist = (((512 + avg_r) * dist_r * dist_r) >> 8) +
+                  4 * dist_g * dist_g +
+                  (((767 - avg_r) * dist_b * dist_b) >> 8);
+          else
+            dist = dist_r * dist_r +
+                  dist_g * dist_g +
+                  dist_b * dist_b;
+
+          if (dist < best_dist) {
+            best_dist = dist;
+            best_i = check_i / 3;
+          }
+        }
+
+        buffer[(dark_i ? CR_DARKEN * 256 : 0) + cr_i * 256 + orig_i] = best_i;
+      }
     }
   }
 
