@@ -28,6 +28,7 @@
 #include "hu_stuff.h"
 #include "m_menu.h"
 #include "p_mobj.h"
+#include "p_pspr.h"
 #include "p_spec.h"
 #include "p_tick.h"
 #include "r_data.h"
@@ -37,6 +38,7 @@
 #include "w_wad.h"
 
 #include "dsda.h"
+#include "dsda/demo.h"
 #include "dsda/exhud.h"
 #include "dsda/font.h"
 #include "dsda/global.h"
@@ -64,6 +66,7 @@ void dsda_InitTextHC(dsda_text_t* component, int x_offset, int y_offset, int vpt
 void dsda_InitBlockyHC(dsda_text_t* component, int x_offset, int y_offset, int vpt);
 void dsda_InitPatchHC(dsda_patch_component_t* component, int x_offset, int y_offset, int vpt);
 fixed_t dsda_HexenArmor(player_t* player);
+int dsda_AmmoColor(player_t* player);
 void dsda_DrawBigNumber(int x, int y, int delta_x, int delta_y, int cm, int vpt, int count, int n);
 void dsda_DrawBasicText(dsda_text_t* component);
 void dsda_RefreshHudText(dsda_text_t* component);
