@@ -19,22 +19,27 @@
 
 #include "big_artifact.h"
 
-static dsda_patch_component_t component;
+typedef struct {
+  dsda_patch_component_t component;
+} local_component_t;
 
-void dsda_InitBigArtifactHC(int x_offset, int y_offset, int vpt) {
-  dsda_InitPatchHC(&component, x_offset, y_offset, vpt);
+static local_component_t* local;
+
+void dsda_InitBigArtifactHC(int x_offset, int y_offset, int vpt, int* args, int arg_count, void** data) {
+  *data = Z_Calloc(1, sizeof(local_component_t));
+  local = *data;
+
+  dsda_InitPatchHC(&local->component, x_offset, y_offset, vpt);
 }
 
-void dsda_UpdateBigArtifactHC(void) {
-  return;
+void dsda_UpdateBigArtifactHC(void* data) {
+  local = data;
 }
 
-void dsda_DrawBigArtifactHC(void) {
+void dsda_DrawBigArtifactHC(void* data) {
   extern void DrawArtifact(int x, int y, int vpt);
 
-  DrawArtifact(component.x, component.y, component.vpt);
-}
+  local = data;
 
-void dsda_EraseBigArtifactHC(void) {
-  return;
+  DrawArtifact(local->component.x, local->component.y, local->component.vpt);
 }
