@@ -18,9 +18,8 @@
 #ifndef __DSDA_HUD_COMPONENT_COORDINATE_DISPLAY__
 #define __DSDA_HUD_COMPONENT_COORDINATE_DISPLAY__
 
-void dsda_InitCoordinateDisplayHC(int x_offset, int y_offset, int vpt_flags);
-void dsda_UpdateCoordinateDisplayHC(void);
-void dsda_DrawCoordinateDisplayHC(void);
-void dsda_EraseCoordinateDisplayHC(void);
+void dsda_InitCoordinateDisplayHC(int x_offset, int y_offset, int vpt_flags, int* args, int arg_count, void** data);
+void dsda_UpdateCoordinateDisplayHC(void* data);
+void dsda_DrawCoordinateDisplayHC(void* data);
 
 #endif
