@@ -18,9 +18,8 @@
 #ifndef __DSDA_HUD_COMPONENT_STAT_TOTALS__
 #define __DSDA_HUD_COMPONENT_STAT_TOTALS__
 
-void dsda_InitStatTotalsHC(int x_offset, int y_offset, int vpt_flags);
-void dsda_UpdateStatTotalsHC(void);
-void dsda_DrawStatTotalsHC(void);
-void dsda_EraseStatTotalsHC(void);
+void dsda_InitStatTotalsHC(int x_offset, int y_offset, int vpt_flags, int* args, int arg_count, void** data);
+void dsda_UpdateStatTotalsHC(void* data);
+void dsda_DrawStatTotalsHC(void* data);
 
 #endif
