@@ -80,7 +80,7 @@ void dsda_UpdateNextMapInfo(void);
 int dsda_ResolveCLEV(int* episode, int* map);
 int dsda_ResolveINIT(void);
 int dsda_MusicIndexToLumpNum(int music_index);
-void dsda_MapMusic(int* music_index, int* music_lump);
+void dsda_MapMusic(int* music_index, int* music_lump, int episode, int map);
 void dsda_IntermissionMusic(int* music_index, int* music_lump);
 void dsda_InterMusic(int* music_index, int* music_lump);
 void dsda_StartFinale(void);
