@@ -37,7 +37,7 @@ void dsda_HexenUpdateNextMapInfo(void);
 int dsda_HexenResolveCLEV(int* clev, int* episode, int* map);
 int dsda_HexenResolveINIT(int* init);
 int dsda_HexenMusicIndexToLumpNum(int* lump, int music_index);
-int dsda_HexenMapMusic(int* music_index, int* music_lump);
+int dsda_HexenMapMusic(int* music_index, int* music_lump, int episode, int map);
 int dsda_HexenIntermissionMusic(int* music_index, int* music_lump);
 int dsda_HexenInterMusic(int* music_index, int* music_lump);
 int dsda_HexenStartFinale(void);
