@@ -43,8 +43,8 @@ typedef struct playpal_data_s {
   // See r_patch.c
   int transparent;
   int duplicate;
-  int black;
-  int white;
+  int darkest;
+  int lightest;
 
   // Array of SDL_Color structs used for setting the 256-colour palette
   SDL_Color* colours;
