@@ -24,7 +24,7 @@
 
 void dsda_InitSettings(void);
 int dsda_CompatibilityLevel(void);
-void dsda_SetTas(void);
+void dsda_SetTas(dboolean t);
 dboolean dsda_ViewBob(void);
 dboolean dsda_WeaponBob(void);
 dboolean dsda_ShowMessages(void);
