@@ -867,7 +867,7 @@ void F_Drawer (void)
     {
       // CPhipps - patch drawing updated
       case 1:
-           if ( gamemode == retail || gamemode == commercial )
+           if ( (gamemode == retail && !pwad_help2_check) || gamemode == commercial )
              V_DrawNamePatch(0, 0, 0, "CREDIT", CR_DEFAULT, VPT_STRETCH);
            else
              V_DrawNamePatch(0, 0, 0, "HELP2", CR_DEFAULT, VPT_STRETCH);
