@@ -48,6 +48,9 @@ void F_Ticker (void);
 void F_Drawer (void);
 
 void F_StartFinale (void);
+void F_StartCast (const char* background, const char* music, dboolean loop_music);
+void F_StartScroll (const char* right, const char* left, const char* music, dboolean loop_music);
+void F_StartPostFinale (void);
 dboolean F_BlockingInput(void);
 
 #endif
