@@ -754,7 +754,7 @@ void gld_StartFuzz(int sprite, float ratio)
   // for indexed lightmode, the fuzz color needs to take
   // pain/item fades and gamma into account, so do a color
   // lookup based on the closest-to-black color index.
-  color = gld_LookupIndexedColor(invul_cm ? playpal_white : playpal_black, true);
+  color = gld_LookupIndexedColor(invul_cm ? playpal_lightest : playpal_darkest, true);
   glColor3f((float)color.r/255.0f,
             (float)color.g/255.0f,
             (float)color.b/255.0f);
@@ -854,7 +854,7 @@ void gld_DrawShaded(int x, int y, int width, int height, int shade)
   // The `col` fixes the menu overlay from inverting during `invul_cm`.
   // The 'automap` boolean is to undo the `col` invert for the automap.
   dboolean automap = V_IsAutomapLightmodeIndexed();
-  int col = invul_cm && !automap ? playpal_white : playpal_black;
+  int col = invul_cm && !automap ? 256 : 0;
   color_rgb_t color = gld_LookupIndexedColor(col, V_IsUILightmodeIndexed() || V_IsAutomapLightmodeIndexed());
 
   glsl_PushNullShader();
