@@ -139,7 +139,7 @@ void gld_AddSkyTexture(GLWall *wall, int sky1, int sky2, int skytype)
 {
   side_t *s = NULL;
   line_t *l = NULL;
-  int sky = skytexture;
+  int sky = texturetranslation[skytexture];
 
   wall->gltexture = NULL;
 
@@ -186,12 +186,7 @@ void gld_AddSkyTexture(GLWall *wall, int sky1, int sky2, int skytype)
       wall->skyyaw = skyXShift;
       wall->skypitch = skyYShift;
       // Choose offset based on logic from r_sky.c
-      if (h >= 128 && h < 200)
-        wall->skyoffset = -28.0f / 128.0f;
-      else if (h > 200)
-        wall->skyoffset = (200 - h) / 128.0f;
-      else
-        wall->skyoffset = 0.0f;
+      wall->skyoffset = skytexturemid / (float)FRACUNIT / h;
       wall->flag = GLDWF_SKY;
     }
   }
@@ -248,7 +243,7 @@ void gld_SkyTransform(GLWall* wall)
   float flipx = wall->flag == GLDWF_SKYFLIP ? -1.0 : 1.0;
   // Scale factors
   float scalex = scale_correction / skyscale * flipx;
-  float scaley = scale_correction * ratio * (skystretch ? 2.0 : 1.0f) / skyscale;
+  float scaley = scale_correction * ratio * (skystretch ? ( (float)SKYSTRETCH_HEIGHT / h ) : 1.0f) / skyscale;
   // Translations
   float transx = wall->skyyaw * tilex * flipx;
   float transy = wall->skypitch * tiley;
