@@ -84,10 +84,14 @@ static void cheat_kfa();
 static void cheat_noclip();
 static void cheat_pw();
 static void cheat_behold();
+static void cheat_clev0();
 static void cheat_clev();
 static void cheat_mypos();
 static void cheat_rate();
+static void cheat_comp0();
 static void cheat_comp();
+static void cheat_skill0();
+static void cheat_skill();
 static void cheat_friction();
 static void cheat_pushers();
 static void cheat_massacre();
@@ -163,10 +167,14 @@ cheatseq_t cheat[] = {
   CHEAT("idbeholdl",  "Lite-Amp Goggles", cht_always, cheat_pw, pw_infrared, false),
   CHEAT("idbehold",   "BEHOLD menu",      cht_always, cheat_behold, 0, false),
   CHEAT("idclev",     "Level Warp",       not_demo | not_menu, cheat_clev, -2, false),
+  CHEAT("idclev",     "Level Warp",       not_demo | not_menu, cheat_clev0, 0, false),
   CHEAT("idmypos",    NULL,               cht_always, cheat_mypos, 0, false),
   CHEAT("idrate",     "Frame rate",       cht_always, cheat_rate, 0, false),
   // phares
   CHEAT("tntcomp",    NULL,               not_demo, cheat_comp, -2, false),
+  CHEAT("tntcomp",    NULL,               not_demo, cheat_comp0, 0, false),
+  CHEAT("skill",      NULL,               not_demo, cheat_skill, -1, false),
+  CHEAT("skill",      NULL,               not_demo, cheat_skill0, 0, false),
   // jff 2/01/98 kill all monsters
   CHEAT("tntem",      NULL,               not_demo, cheat_massacre, 0, false),
   // killough 2/07/98: moved from am_map.c
@@ -257,6 +265,7 @@ char buf[3];
 {
   int musnum, muslump;
   int epsd, map;
+  char *mapname;
 
   //jff 3/20/98 note: this cheat allowed in netgame/demorecord
 
@@ -271,23 +280,28 @@ char buf[3];
   }
   else
   {
-    epsd = buf[0] - '1';
-    map = buf[1] - '1';
+    epsd = buf[0] - '0';
+    map = buf[1] - '0';
   }
 
-  dsda_AddMessage(s_STSTR_MUS);
-
   idmusnum = -1;
   dsda_MapMusic(&musnum, &muslump, epsd, map);
   idmusnum = musnum; //jff 3/17/98 remember idmus number for restore
 
-  if (muslump != -1)
+  mapname = VANILLA_MAP_LUMP_NAME(epsd,map);
+
+  if (W_LumpNameExists(mapname))
   {
-    S_ChangeMusInfoMusic(muslump, true);
-  }
-  else if (musnum != -1)
-  {
-    S_ChangeMusic(musnum, 1);
+    doom_printf("%s: %s", s_STSTR_MUS, mapname);
+
+    if (muslump != -1)
+    {
+      S_ChangeMusInfoMusic(muslump, true);
+    }
+    else if (musnum != -1)
+    {
+      S_ChangeMusic(musnum, 1);
+    }
   }
   else
   {
@@ -481,6 +495,24 @@ static void cheat_behold()
   dsda_AddMessage(s_STSTR_BEHOLD);
 }
 
+// check 'clev' change-level cheat
+static void cheat_clev0()
+{
+  int epsd, map;
+  char *cur, *next;
+  cur = Z_Strdup(VANILLA_MAP_LUMP_NAME(gameepisode, gamemap));
+
+  dsda_NextMap(&epsd, &map);
+  next = VANILLA_MAP_LUMP_NAME(epsd, map);
+
+  if (W_LumpNameExists(next))
+    doom_printf("Current: %s, next: %s", cur, next);
+  else
+    doom_printf("Current: %s", cur);
+
+  Z_Free(cur);
+}
+
 // 'clev' change-level cheat
 static void cheat_clev(char buf[3])
 {
@@ -517,22 +549,60 @@ static void cheat_rate()
   dsda_ToggleRenderStats();
 }
 
-// compatibility cheat
+// check compatibility cheat
+static void cheat_comp0()
+{
+  if (raven)
+    return doom_printf("Cheat disabled for %s", heretic ? "Heretic" : "Hexen");
 
+  doom_printf("Complevel: %i - %s", compatibility_level, comp_lev_str[compatibility_level]);
+}
+
+// compatibility cheat
 static void cheat_comp(char buf[3])
 {
-  compatibility_level = (buf[0] - '0') * 10 + buf[1] - '0';
+  int compinput = (buf[0] - '0') * 10 + buf[1] - '0';
 
-  if (compatibility_level < 0 ||
-      compatibility_level >= MAX_COMPATIBILITY_LEVEL ||
-      (compatibility_level > 17 && compatibility_level < 21))
+  if (raven) return;
+
+  if (compinput < 0 ||
+      compinput >= MAX_COMPATIBILITY_LEVEL ||
+      (compinput > 17 && compinput < 21))
   {
-    doom_printf("Invalid complevel");
+    return; //doom_printf("Invalid complevel");
   }
   else
   {
+    compatibility_level = compinput;
     G_Compatibility(); // this is missing options checking
-    doom_printf("%s", comp_lev_str[compatibility_level]);
+    doom_printf("New Complevel: %i - %s", compatibility_level, comp_lev_str[compatibility_level]);
+  }
+}
+
+// Check skill cheat
+static void cheat_skill0()
+{
+  if (raven || tc_game)
+    return doom_printf("Skill: %i", gameskill + 1);
+
+  doom_printf("Skill: %i - %s", gameskill + 1, skill_str[gameskill + 1]);
+}
+
+// Skill cheat
+static void cheat_skill(char buf[1])
+{
+  int skill = buf[0] - '0';
+
+  if (skill >= 1 && skill <= 5)
+  {
+    gameskill = skill - 1;
+
+    if (raven || tc_game)
+      doom_printf("Next Level Skill: %i", gameskill + 1);
+    else
+      doom_printf("Next Level Skill: %i - %s", gameskill + 1, skill_str[gameskill + 1]);
+
+    dsda_UpdateGameSkill(gameskill);
   }
 }
 
