@@ -64,6 +64,7 @@
 #include "dsda/configuration.h"
 #include "dsda/exhud.h"
 #include "dsda/map_format.h"
+#include "dsda/mapinfo.h"
 #include "dsda/render_stats.h"
 #include "dsda/settings.h"
 #include "dsda/signal_context.h"
@@ -86,6 +87,8 @@ int r_frame_count;
 
 #define HEXEN_PI 3.141592657
 
+#define FIXED2DOUBLE(x) ((x)/(double)FRACUNIT)
+
 int validcount = 1;         // increment every time a check is made
 int validcount2 = 1;
 const lighttable_t *fixedcolormap;
@@ -140,6 +143,9 @@ int viewangletox[FINEANGLES/2];
 // e6y: resolution limitation is removed
 angle_t *xtoviewangle;   // killough 2/8/98
 
+// [FG] linear horizontal sky scrolling
+angle_t *linearskyangle;
+
 // killough 3/20/98: Support dynamic colormaps, e.g. deep water
 // killough 4/4/98: support dynamic number of them as well
 
@@ -151,6 +157,8 @@ const lighttable_t *(*zlight)[MAXLIGHTZ];
 const lighttable_t *fullcolormap;
 const lighttable_t **colormaps;
 
+const byte* colormap_lump;
+
 // killough 3/20/98, 4/4/98: end dynamic colormaps
 
 //e6y: for Boom colormaps in OpenGL mode
@@ -361,7 +369,8 @@ angle_t R_PointToPseudoAngle (fixed_t x, fixed_t y)
 
 static void R_InitTextureMapping (void)
 {
-  int i,x;
+  int i,x,angle;
+  double linearskyfactor;
   FieldOfView = FIELDOFVIEW;
 
   // For widescreen displays, increase the FOV so that the middle part of the
@@ -409,11 +418,17 @@ static void R_InitTextureMapping (void)
   //  xtoviewangle will give the smallest view angle
   //  that maps to x.
 
+  linearskyfactor = FIXED2DOUBLE(finetangent[FINEANGLES/4 + FieldOfView/2]) * ANG90;
+
   for (x=0; x<=viewwidth; x++)
     {
       for (i=0; viewangletox[i] > x; i++)
         ;
       xtoviewangle[x] = (i<<ANGLETOFINESHIFT)-ANG90;
+
+      // [FG] linear horizontal sky scrolling
+      angle = (0.5 - x / (double)viewwidth) * linearskyfactor;
+      linearskyangle[x] = (angle >= 0) ? angle : ANGLE_MAX + angle;
     }
 
   // Take out the fencepost cases from viewangletox.
@@ -487,11 +502,13 @@ static void R_InitLightTables (void)
 // The change will take effect next refresh.
 //
 
+extern dboolean BorderNeedRefresh;
 dboolean setsizeneeded;
 static int setblocks;
 
 void R_SetViewSize(void)
 {
+  BorderNeedRefresh = true;
   setsizeneeded = true;
   setblocks = dsda_IntConfig(dsda_config_screenblocks);
 }
@@ -798,6 +815,50 @@ subsector_t *R_PointInSubsector(fixed_t x, fixed_t y)
   return &subsectors[nodenum & ~NF_SUBSECTOR];
 }
 
+sector_t *R_PointInSector(fixed_t x, fixed_t y)
+{
+  return R_PointInSubsector(x, y)->sector;
+}
+
+void R_SectorCenter(fixed_t *x, fixed_t *y, sector_t *sec)
+{
+  int i;
+  *x = 0;
+  *y = 0;
+
+  if (!sec->linecount)
+    return;
+
+  for (i = 0; i < sec->linecount; ++i)
+  {
+    *x += sec->lines[i]->v1->x;
+    *y += sec->lines[i]->v1->y;
+  }
+
+  *x /= sec->linecount;
+  *y /= sec->linecount;
+
+  if (R_PointInSector(*x, *y) != sec)
+  {
+    *x = sec->lines[0]->v1->x;
+    *y = sec->lines[0]->v1->y;
+  }
+}
+
+void R_LineCenter(fixed_t *x, fixed_t *y, line_t *line)
+{
+  if (!line->v1 || !line->v2)
+  {
+    *x = 0;
+    *y = 0;
+
+    return;
+  }
+
+  *x = (line->v1->x + line->v2->x) / 2;
+  *y = (line->v1->y + line->v2->y) / 2;
+}
+
 //
 // R_SetupFreelook
 //
@@ -881,16 +942,19 @@ static void R_SetupFrame (player_t *player)
 
   // killough 3/20/98, 4/4/98: select colormap based on player status
 
-  if (player->mo->subsector->sector->heightsec != -1)
-    {
-      const sector_t *s = player->mo->subsector->sector->heightsec + sectors;
-      cm = viewz < s->floorheight ? s->bottommap : viewz > s->ceilingheight ?
-        s->topmap : s->midmap;
-      if (cm < 0 || cm > numcolormaps)
-        cm = 0;
-    }
+  if (player->mo->subsector->sector->colormap)
+    cm = player->mo->subsector->sector->colormap;
+  else if (player->mo->subsector->sector->heightsec != -1)
+  {
+    const sector_t *s = player->mo->subsector->sector->heightsec + sectors;
+    cm = viewz < s->floorheight ? s->bottommap :
+         viewz > s->ceilingheight ? s->topmap :
+         s->midmap;
+    if (cm < 0 || cm > numcolormaps)
+      cm = 0;
+  }
   else
-    cm = 0;
+    cm = map_info.default_colormap;
 
   //e6y: save previous and current colormap
   boom_cm = cm;
