@@ -115,10 +115,12 @@ static int maxframe;
 void R_InitSpritesRes(void)
 {
   if (xtoviewangle) Z_Free(xtoviewangle);
+  if (linearskyangle) Z_Free (linearskyangle);
   if (negonearray) Z_Free(negonearray);
   if (screenheightarray) Z_Free(screenheightarray);
 
   xtoviewangle = Z_Calloc(1, (SCREENWIDTH + 1) * sizeof(*xtoviewangle));
+  linearskyangle = Z_Calloc(1, (SCREENWIDTH + 1) * sizeof(*linearskyangle));
   negonearray = Z_Calloc(1, SCREENWIDTH * sizeof(*negonearray));
   screenheightarray = Z_Calloc(1, SCREENWIDTH * sizeof(*screenheightarray));
 
@@ -1059,34 +1061,25 @@ static void R_DrawPSprite (pspdef_t *psp)
   flip = (dboolean)(sprframe->flip & 1);
 
   {
-    weaponinfo_t *winfo;
-    int state;
-    int weapon_attack_alignment;
+    int weapon_attack_alignment = dsda_IntConfig(dsda_config_weapon_attack_alignment);
 
-    if (hexen)
-    {
-      winfo = &hexen_weaponinfo[viewplayer->readyweapon][viewplayer->pclass];
-    }
-    else
-    {
-      winfo = &weaponinfo[viewplayer->readyweapon];
-    }
+    // [crispy] don't align swiping weapons
+    const dboolean swiping_weapon = hexen && (viewplayer->pclass == PCLASS_FIGHTER ||
+                                             (viewplayer->pclass == PCLASS_CLERIC &&
+                                             viewplayer->readyweapon == wp_first));
 
-    state = viewplayer->psprites[ps_weapon].state - states;
-    weapon_attack_alignment = dsda_IntConfig(dsda_config_weapon_attack_alignment);
-
-    if (!dsda_WeaponBob())
+    if (!dsda_WeaponBob() && !(swiping_weapon && viewplayer->attackdown))
     {
       static fixed_t last_sy = 32 * FRACUNIT;
 
       psp_sx = FRACUNIT;
 
-      if (state != winfo->downstate && state != winfo->upstate)
+      if (psp->state->action != A_Lower && psp->state->action != A_Raise)
       {
         last_sy = psp->sy;
         psp_sy = 32 * FRACUNIT;
       }
-      else if (state == winfo->downstate)
+      else if (psp->state->action == A_Lower)
       {
         // We want to move smoothly from where we were
         psp_sy -= (last_sy - 32 * FRACUNIT);
@@ -1098,11 +1091,16 @@ static void R_DrawPSprite (pspdef_t *psp)
 
       // [crispy] don't center vertically during lowering and raising states
       if (weapon_attack_alignment >= CENTERWEAPON_HORVER &&
-          state != winfo->downstate && state != winfo->upstate)
+          psp->state->action != A_Lower && psp->state->action != A_Raise && !swiping_weapon)
       {
           R_ApplyWeaponBob(NULL, false, &psp_sy, weapon_attack_alignment == CENTERWEAPON_BOB);
       }
     }
+    else if (psp->state->action == A_WeaponReady && psp->state->tics > 1 && movement_smooth)
+    {
+      // Interpolate bobbing for animated weapons (Chainsaw)
+      R_ApplyWeaponBob(&psp_sx, true, &psp_sy, true);
+    }
   }
 
   {
@@ -1229,18 +1227,22 @@ static void R_DrawPSprite (pspdef_t *psp)
     psp_inter.x1_prev = vis->x1;
     psp_inter.texturemid_prev = vis->texturemid;
 
-    if (lump == psp_inter.lump)
+    // Do not interpolate on the first tic of the level
+    if (leveltime > 1)
     {
-      int deltax = vis->x2 - vis->x1;
-      vis->x1 = psp_inter.x1 + FixedMul (tic_vars.frac, (vis->x1 - psp_inter.x1));
-      vis->x2 = vis->x1 + deltax;
-      vis->texturemid = psp_inter.texturemid + FixedMul (tic_vars.frac, (vis->texturemid - psp_inter.texturemid));
-    }
-    else
-    {
-      psp_inter.x1 = vis->x1;
-      psp_inter.texturemid = vis->texturemid;
-      psp_inter.lump=lump;
+      if (lump == psp_inter.lump)
+      {
+        int deltax = vis->x2 - vis->x1;
+        vis->x1 = psp_inter.x1 + FixedMul (tic_vars.frac, (vis->x1 - psp_inter.x1));
+        vis->x2 = vis->x1 + deltax;
+        vis->texturemid = psp_inter.texturemid + FixedMul (tic_vars.frac, (vis->texturemid - psp_inter.texturemid));
+      }
+      else
+      {
+        psp_inter.x1 = vis->x1;
+        psp_inter.texturemid = vis->texturemid;
+        psp_inter.lump=lump;
+      }
     }
   }
 
