@@ -40,7 +40,7 @@
 #include "r_main.h"
 #include "lprintf.h"
 
-int sts_always_red;      //jff 2/18/98 control to disable status color changes
+int sts_colored_numbers; //jff 2/18/98 control to enable status color changes
 int sts_pct_always_gray; // killough 2/21/98: always gray %'s? bug or feature?
 
 //
@@ -141,7 +141,7 @@ static void STlib_drawNum
   if (!num)
     // CPhipps - patch drawing updated, reformatted
     V_DrawNumPatch(x - w, n->y, FG, n->p[0].lumpnum, cm,
-       (((cm!=CR_DEFAULT) && !sts_always_red) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
+       (((cm!=CR_DEFAULT) && sts_colored_numbers) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
 
   // draw the new number
   //jff 2/16/98 add color translation to digit output
@@ -149,7 +149,7 @@ static void STlib_drawNum
     // CPhipps - patch drawing updated, reformatted
     x -= w;
     V_DrawNumPatch(x, n->y, FG, n->p[num % 10].lumpnum, cm,
-       (((cm!=CR_DEFAULT) && !sts_always_red) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
+       (((cm!=CR_DEFAULT) && sts_colored_numbers) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
     num /= 10;
   }
 
@@ -158,7 +158,7 @@ static void STlib_drawNum
   // cph - patch drawing updated, load by name instead of acquiring pointer earlier
   if (neg)
     V_DrawNamePatch(x - w, n->y, FG, "STTMINUS", cm,
-       (((cm!=CR_DEFAULT) && !sts_always_red) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
+       (((cm!=CR_DEFAULT) && sts_colored_numbers) ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
 }
 
 /*
@@ -226,7 +226,7 @@ void STlib_updatePercent
     // CPhipps - patch drawing updated
     V_DrawNumPatch(per->n.x, per->n.y, FG, per->p->lumpnum,
        sts_pct_always_gray ? CR_GRAY : cm,
-       (sts_always_red ? VPT_NONE : VPT_TRANS) | VPT_ALIGN_BOTTOM);
+       (sts_colored_numbers ? VPT_TRANS : VPT_NONE) | VPT_ALIGN_BOTTOM);
   }
 
   STlib_updateNum(&per->n, cm, refresh);
