@@ -480,6 +480,9 @@ static int ST_calcPainOffset(void)
 //  dead > evil grin > turned head > straight ahead
 //
 
+// [crispy] fix status bar face hysteresis
+static int faceindex;
+
 static void ST_updateFaceWidget(void)
 {
   int         i;
@@ -489,13 +492,19 @@ static void ST_updateFaceWidget(void)
   static int  priority = 0;
   dboolean     doevilgrin;
 
+  // [crispy] fix status bar face hysteresis
+  int		painoffset;
+
+  painoffset = ST_calcPainOffset();
+
   if (priority < 10)
     {
       // dead
       if (!plyr->health)
         {
           priority = 9;
-          st_faceindex = ST_DEADFACE;
+          painoffset = 0;
+          faceindex = ST_DEADFACE;
           st_facecount = 1;
         }
     }
@@ -520,7 +529,7 @@ static void ST_updateFaceWidget(void)
               // evil grin if just picked up weapon
               priority = 8;
               st_facecount = ST_EVILGRINCOUNT;
-              st_faceindex = ST_calcPainOffset() + ST_EVILGRINOFFSET;
+              faceindex = ST_EVILGRINOFFSET;
             }
         }
 
@@ -549,7 +558,7 @@ static void ST_updateFaceWidget(void)
                 priority = 8;
 
               st_facecount = ST_TURNCOUNT;
-              st_faceindex = ST_calcPainOffset() + ST_OUCHOFFSET;
+              faceindex = ST_OUCHOFFSET;
             }
           else
             {
@@ -573,22 +582,21 @@ static void ST_updateFaceWidget(void)
 
 
               st_facecount = ST_TURNCOUNT;
-              st_faceindex = ST_calcPainOffset();
 
               if (diffang < ANG45)
                 {
                   // head-on
-                  st_faceindex += ST_RAMPAGEOFFSET;
+                  faceindex = ST_RAMPAGEOFFSET;
                 }
               else if (i)
                 {
                   // turn face right
-                  st_faceindex += ST_TURNOFFSET;
+                  faceindex = ST_TURNOFFSET;
                 }
               else
                 {
                   // turn face left
-                  st_faceindex += ST_TURNOFFSET+1;
+                  faceindex = ST_TURNOFFSET+1;
                 }
             }
         }
@@ -609,13 +617,13 @@ static void ST_updateFaceWidget(void)
             {
               priority = 7;
               st_facecount = ST_TURNCOUNT;
-              st_faceindex = ST_calcPainOffset() + ST_OUCHOFFSET;
+              faceindex = ST_OUCHOFFSET;
             }
           else
             {
               priority = 6;
               st_facecount = ST_TURNCOUNT;
-              st_faceindex = ST_calcPainOffset() + ST_RAMPAGEOFFSET;
+              faceindex = ST_RAMPAGEOFFSET;
             }
 
         }
@@ -632,7 +640,7 @@ static void ST_updateFaceWidget(void)
           else if (!--lastattackdown)
             {
               priority = 5;
-              st_faceindex = ST_calcPainOffset() + ST_RAMPAGEOFFSET;
+              faceindex = ST_RAMPAGEOFFSET;
               st_facecount = 1;
               lastattackdown = 1;
             }
@@ -650,7 +658,8 @@ static void ST_updateFaceWidget(void)
         {
           priority = 4;
 
-          st_faceindex = ST_GODFACE;
+          painoffset = 0;
+          faceindex = ST_GODFACE;
           st_facecount = 1;
 
         }
@@ -660,13 +669,15 @@ static void ST_updateFaceWidget(void)
   // look left or look right if the facecount has timed out
   if (!st_facecount)
     {
-      st_faceindex = ST_calcPainOffset() + (st_randomnumber % 3);
+      faceindex = st_randomnumber % 3;
       st_facecount = ST_STRAIGHTFACECOUNT;
       priority = 0;
     }
 
   st_facecount--;
 
+  // [crispy] fix status bar face hysteresis
+  st_faceindex = painoffset + faceindex;
 }
 
 int sts_traditional_keys; // killough 2/28/98: traditional status bar keys
@@ -764,7 +775,7 @@ static void ST_doPaletteStuff(void)
       // radiation suit palette is used to tint the screen green,
       // as though the player is being covered in goo by an
       // attacking flemoid.
-      if (gamemission == chex)
+      if (gamemission == tc_chex)
       {
         palette = RADIATIONPAL;
       }
@@ -1031,6 +1042,7 @@ static void ST_initData(void)
 
   st_statusbaron = true;
 
+  faceindex = 0; // [crispy] fix status bar face hysteresis across level changes
   st_faceindex = 0;
   st_palette = -1;
 
